Axial

Struct Axial 

pub struct Axial {
    pub q: i32,
    pub r: i32,
}
Axial coordinates use the same system as cube coordinates, but only store two of the coordinate values. This is possible since, for cube coordinate (x, y, z), the third value can always be calculated when the other two are known due to the constraint x + y + z == 0.

Fields

q: i32r: i32

Implementations

Source

impl Axial

pub const ORIGIN: Axial

Axial coordinate origin of (0, 0).

pub fn from_coords(q: i32, r: i32) -> Self

For two unsigned 32-bit integers x and y, the corresponding axial coordinate is (x, y).

Examples
use chickenwire::coordinate::axial::Axial;

assert_eq!(Axial::from((1, 2)), Axial::from_coords(1, 2));
pub fn neighbors(self) -> Vec<Self>

[ docs missing ]

pub fn diagonals(self) -> Vec<Self>

[ docs missing ]

pub fn dist(self, other: Self) -> i32

Determines the distance between two axial coordinates.

Examples
use chickenwire::coordinate::axial::Axial;

let origin = Axial::ORIGIN;
let coord_1 = Axial { q: 1, r: -3 };
let coord_2 = Axial { q: -8, r: 2 };

assert_eq!(origin.dist(coord_1), 3);
assert_eq!(coord_1.dist(origin), 3);
assert_eq!(coord_1.dist(coord_1), 0);
assert_eq!(coord_2.dist(coord_1), 9);