pub struct Axial {
pub q: i32,
pub r: i32,
}Expand description
Axial coordinates use the same system as cube coordinates, but only store two of the coordinate values. This is possible since, for cube coordinate (x, y, z), the third value can always be calculated when the other two are known due to the constraint x + y + z == 0.
Fields
q: i32r: i32Implementations
Sourceimpl Axial
impl Axial
Sourcepub fn from_coords(q: i32, r: i32) -> Self
pub fn from_coords(q: i32, r: i32) -> Self
For two unsigned 32-bit integers x and y, the corresponding axial coordinate is (x, y).
Examples
use chickenwire::coordinate::axial::Axial;
assert_eq!(Axial::from((1, 2)), Axial::from_coords(1, 2));Sourcepub fn dist(self, other: Self) -> i32
pub fn dist(self, other: Self) -> i32
Determines the distance between two axial coordinates.
Examples
use chickenwire::coordinate::axial::Axial;
let origin = Axial::ORIGIN;
let coord_1 = Axial { q: 1, r: -3 };
let coord_2 = Axial { q: -8, r: 2 };
assert_eq!(origin.dist(coord_1), 3);
assert_eq!(coord_1.dist(origin), 3);
assert_eq!(coord_1.dist(coord_1), 0);
assert_eq!(coord_2.dist(coord_1), 9);Trait Implementations
Sourceimpl Add for Axial
Adds two Axial coordinates in the same manner as vectors.
impl Add for Axial
Adds two Axial coordinates in the same manner as vectors.
Examples
use chickenwire::coordinate::axial::Axial;
let coord_1 = Axial::from_coords(1, -3);
let coord_2 = Axial::from_coords(-5, 12);
assert_eq!(coord_1 + coord_2, Axial::from_coords(-4, 9));
assert_eq!(coord_2 + coord_1, Axial::from_coords(-4, 9));Sourceimpl Div<i32> for Axial
Divides an Axial coordinate by an i32 scalar, like a vector. Values
are truncated (i.e. rounded toward zero).
impl Div<i32> for Axial
Divides an Axial coordinate by an i32 scalar, like a vector. Values
are truncated (i.e. rounded toward zero).
Sourceimpl From<(i32, i32)> for Axial
Creates an Axial from an (i32, i32).
impl From<(i32, i32)> for Axial
Creates an Axial from an (i32, i32).
Examples
use chickenwire::coordinate::axial::Axial;
assert_eq!(
Axial::from((1, 2)),
Axial { q: 1, r: 2 }
);Sourceimpl From<Axial> for Cube
For axial coordinate (q, r), cube coordinate (x, y, z) is calculated by
solving for y based upon the constraint x + y + z == 0, where x == q and
z == r.
impl From<Axial> for Cube
For axial coordinate (q, r), cube coordinate (x, y, z) is calculated by solving for y based upon the constraint x + y + z == 0, where x == q and z == r.
Examples
use chickenwire::coordinate::axial::Axial;
use chickenwire::coordinate::cube::Cube;
let axial = Axial::from_coords(1, 2);
assert_eq!(Cube::from(Axial::ORIGIN), Cube::ORIGIN);
assert_eq!(Cube::from(axial), Cube::force_from_coords(1, -3, 2));Sourceimpl From<Axial> for MultiCoord
Creates a MultiCoord from an Axial.
impl From<Axial> for MultiCoord
Creates a MultiCoord from an Axial.
Sourceimpl From<Cube> for Axial
Creates an Axial from a Cube.
impl From<Cube> for Axial
Creates an Axial from a Cube.
Examples
use chickenwire::coordinate::axial::Axial;
use chickenwire::coordinate::cube::Cube;
let cube = Cube::force_from_coords(1, 2, -3);
assert_eq!(
Axial::from(cube),
Axial { q: 1, r: -3 }
);
assert_eq!(
Axial::from(Cube::ORIGIN),
Axial::ORIGIN
);Sourceimpl From<MultiCoord> for Axial
Creates an Axial from a MultiCoord.
impl From<MultiCoord> for Axial
Creates an Axial from a MultiCoord.
Conversion from both axial and cube MultiCoords is supported.
Panics
Panics when parsing a double or offset MultiCoord.
Sourcefn from(coord: MultiCoord) -> Self
fn from(coord: MultiCoord) -> Self
Sourceimpl Mul<i32> for Axial
Multiplies an Axial coordinate by an i32 scalar, like a vector.
impl Mul<i32> for Axial
Multiplies an Axial coordinate by an i32 scalar, like a vector.
Examples
use chickenwire::coordinate::axial::Axial;
let coord = Axial::from_coords(1, -3);
assert_eq!(-1 * coord, Axial::from_coords(-1, 3));
assert_eq!(0 * coord, Axial::ORIGIN);
assert_eq!(coord * 2, Axial::from_coords(2, -6));Sourceimpl Ord for Axial
impl Ord for Axial
Sourceimpl PartialOrd for Axial
impl PartialOrd for Axial
Sourceimpl Sub for Axial
Subtracts two Axial coordinates in the same manner as vectors.
impl Sub for Axial
Subtracts two Axial coordinates in the same manner as vectors.
Examples
use chickenwire::coordinate::axial::Axial;
let coord_1 = Axial::from_coords(1, -3);
let coord_2 = Axial::from_coords(5, -12);
assert_eq!(coord_1 - coord_2, Axial::from_coords(-4, 9));
assert_eq!(coord_2 - coord_1, Axial::from_coords(4, -9));impl Copy for Axial
impl Eq for Axial
impl StructuralPartialEq for Axial